@@ -12,6 +12,7 @@
 
 */
 
+
 pub mod push_to_crates {
 
     pub fn print_dummy_data(data:&str){
@@ -35,7 +36,7 @@ pub mod push_to_crates {
         }
 
 
-        static MAX_BYTES:u16=1799;
+        pub static MAX_BYTES:u16=1799;
 
     }
 
